@@ -3,13 +3,14 @@ package test;
 
 package main;
 
-use Sparrow::Constants;
-use Sparrow::Commands::Plugin;
-use Sparrow::Commands::Project;
-use Sparrow::Commands::Swat;
-use Sparrow::Misc;
 use Carp;
 use Data::Dumper;
 
+use Sparrow::Constants;
+use Sparrow::Commands::Plugin;
+use Sparrow::Commands::Project;
+use Sparrow::Commands::CheckPoint;
+use Sparrow::Misc;
+
 1;
 
